@@ -33,6 +33,7 @@ class VideoExtractor():
 
     def download_by_url(self, url, **kwargs):
         self.url = url
+        self.vid = None
 
         if 'extractor_proxy' in kwargs and kwargs['extractor_proxy']:
             set_proxy(parse_host(kwargs['extractor_proxy']))
@@ -50,6 +51,7 @@ class VideoExtractor():
         self.download(**kwargs)
 
     def download_by_vid(self, vid, **kwargs):
+        self.url = None
         self.vid = vid
 
         if 'extractor_proxy' in kwargs and kwargs['extractor_proxy']:
@@ -90,7 +92,7 @@ class VideoExtractor():
             print("      container:     %s" % stream['container'])
 
         if 'video_profile' in stream:
-            print("      video-profile: %s" % stream['video_profile'])
+            maybe_print("      video-profile: %s" % stream['video_profile'])
 
         if 'quality' in stream:
             print("      quality:       %s" % stream['quality'])
