@@ -2,6 +2,7 @@
 
 import os.path
 import subprocess
+from ..util.strings import parameterize
 
 def get_usable_ffmpeg(cmd):
     try:
@@ -53,7 +54,7 @@ def ffmpeg_concat_mp4_to_mpg(files, output='output.mpg'):
         concat_list = open(output + '.txt', 'w', encoding="utf-8")
         for file in files:
             if os.path.isfile(file):
-                concat_list.write("file '%s'\n" % file)
+                concat_list.write("file %s\n" % parameterize(file))
         concat_list.close()
 
         params = [FFMPEG] + LOGLEVEL
@@ -118,7 +119,7 @@ def ffmpeg_concat_flv_to_mp4(files, output='output.mp4'):
             if os.path.isfile(file):
                 # for escaping rules, see:
                 # https://www.ffmpeg.org/ffmpeg-utils.html#Quoting-and-escaping
-                concat_list.write("file '%s'\n" % file.replace("'", r"'\''"))
+                concat_list.write("file %s\n" % parameterize(file))
         concat_list.close()
 
         params = [FFMPEG] + LOGLEVEL + ['-f', 'concat', '-y', '-i']
@@ -163,18 +164,16 @@ def ffmpeg_concat_mp4_to_mp4(files, output='output.mp4'):
         concat_list = open(output + '.txt', 'w', encoding="utf-8")
         for file in files:
             if os.path.isfile(file):
-                concat_list.write("file '%s'\n" % file)
+                concat_list.write("file %s\n" % parameterize(file))
         concat_list.close()
 
         params = [FFMPEG] + LOGLEVEL + ['-f', 'concat', '-y', '-i']
         params.append(output + '.txt')
         params += ['-c', 'copy', output]
 
-        if subprocess.call(params) == 0:
-            os.remove(output + '.txt')
-            return True
-        else:
-            raise
+        subprocess.check_call(params)
+        os.remove(output + '.txt')
+        return True
 
     for file in files:
         if os.path.isfile(file):
@@ -196,9 +195,7 @@ def ffmpeg_concat_mp4_to_mp4(files, output='output.mp4'):
     else:
         params += ['-c', 'copy', '-absf', 'aac_adtstoasc', output]
 
-    if subprocess.call(params) == 0:
-        for file in files:
-            os.remove(file + '.ts')
-        return True
-    else:
-        raise
+    subprocess.check_call(params)
+    for file in files:
+        os.remove(file + '.ts')
+    return True
